==> mir_0.0.8+13.10.20130730.orig.tar.gz: mir-0.0.8+13.10.20130730/include/server/mir/frontend/protobuf_ipc_factory.h <==
/*
 * Copyright © 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alan Griffiths <alan@octopull.co.uk>
 */

#ifndef MIR_FRONTEND_PROTOBUF_IPC_FACTORY_H_
#define MIR_FRONTEND_PROTOBUF_IPC_FACTORY_H_

#include <memory>

namespace mir
{
namespace events
{
class EventSink;
}
namespace protobuf
{
class DisplayServer;
}
namespace frontend
{
class ResourceCache;
class MessageProcessorReport;

class ProtobufIpcFactory
{
public:
    virtual std::shared_ptr<protobuf::DisplayServer> make_ipc_server(
        std::shared_ptr<events::EventSink> const& sink) = 0;
    virtual std::shared_ptr<ResourceCache> resource_cache() = 0;
    virtual std::shared_ptr<MessageProcessorReport> report() = 0;

protected:
    ProtobufIpcFactory() {}
    virtual ~ProtobufIpcFactory() {}
    ProtobufIpcFactory(ProtobufIpcFactory const&) = delete;
    ProtobufIpcFactory& operator =(ProtobufIpcFactory const&) = delete;
};

}
}

#endif // MIR_FRONTEND_PROTOBUF_IPC_FACTORY_H_

==> mir_0.0.15+13.10.20131014.orig.tar.gz: mir-0.0.15+13.10.20131014/include/server/mir/frontend/protobuf_ipc_factory.h <==
/*
 * Copyright © 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alan Griffiths <alan@octopull.co.uk>
 */

#ifndef MIR_FRONTEND_PROTOBUF_IPC_FACTORY_H_
#define MIR_FRONTEND_PROTOBUF_IPC_FACTORY_H_

#include <memory>

namespace mir
{
namespace protobuf
{
class DisplayServer;
}
namespace frontend
{
class EventSink;
class ResourceCache;
class MessageProcessorReport;

class ProtobufIpcFactory
{
public:
    virtual std::shared_ptr<protobuf::DisplayServer> make_ipc_server(
        std::shared_ptr<EventSink> const& sink, bool authorized_to_resize_display) = 0;
    virtual std::shared_ptr<ResourceCache> resource_cache() = 0;
    virtual std::shared_ptr<MessageProcessorReport> report() = 0;

protected:
    ProtobufIpcFactory() {}
    virtual ~ProtobufIpcFactory() {}
    ProtobufIpcFactory(ProtobufIpcFactory const&) = delete;
    ProtobufIpcFactory& operator =(ProtobufIpcFactory const&) = delete;
};

}
}

#endif // MIR_FRONTEND_PROTOBUF_IPC_FACTORY_H_
